#include <xc.h>
#include "P18F_LCD.h"

void interrupt HighISR(void)
{
    if (TMR0IE && TMR0IF)
    {
        WriteTimer0(65536 - 488); // 500mS Period, 500mS/4uS/256 = 488
        LATDbits.LATD0 = !LATDbits.LATD0;
        TMR0IF = 0;
    }
}

void interrupt low_priority LowISR(void)
{
    if (TMR1IF && TMR1IE)
    {
        WriteTimer1(65536 - 7812); // 250mS Period, 250mS/4uS/8 = 7812
        LATDbits.LATD7 = !LATDbits.LATD7;
        TMR1IF = 0;
    }
}

void main(void)
{
    OSCCONbits.IRCF = 0b100; // Select INTOSC at 1MHz as clock source
    // Tcy = 4uS (Fcy = 250KHz)
    ADCON1bits.PCFG = 0x0f; // Set all ADC multiplexed pins as digital mode

    LCD_L_Delay(); // 開機 LCD 延遲 10mS
    OpenLCD();
    LCD_Set_Cursor(0, 0);
    putrsLCD((const far char*) "Lab3 T0 & T1 Int");
    LCD_Set_Cursor(1, 0);
    putrsLCD((const far char*) "T0 High, T1 Low.");

    T0CON = 0x00;
    T0CON = 0b10000111; // 啟動 Timer0 使用 16-bit Mode, 預除器 1: 256
    WriteTimer0(65536 - 488); // 500mS Period, 500mS/4uS/256 = 488
    INTCON2bits.TMR0IP = 1; // 設定 Timer0 為高優先權中斷
    INTCONbits.T0IE = 1;


    T1CON = 0x00;
    T1CON = 0b10110001; // 啟動 Timer1, 使用 16-bit Mode, 預除器 1:8
    WriteTimer1(65536 - 7812); // 250mS Period, 250mS/4uS/8 = 7812
    IPR1bits.TMR1IP = 0; // 設定 Timer1 為低優先權中斷
    PIE1bits.TMR1IE = 1;

    RCONbits.IPEN = 1;
    INTCONbits.GIEH = 1;
    INTCONbits.GIEL = 1;

    TRISD = 0x00;
    LATD = 0x00; // Turn Off all LEDs

    while (1);
}
